@@ -1,15 +1,15 @@
 createAquifer.base <-
-function(name,area,label,volume,rechargeTS,Sy,leakageFraction,initialStorage,leakageCode,priority)
+function(name,area,volume,rechargeTS,Sy,leakageFraction,initialStorage,leakageObject,priority)
 {
    aquifer<-list(name           =name           ,
                  area           =area           ,
-                 label          =label          ,
+                 label          =runif(1)       ,
                  volume         =volume         ,
                  rechargeTS     =rechargeTS     ,
                  Sy             =Sy             ,
                  leakageFraction=leakageFraction,
                  initialStorage =initialStorage ,
-                 leakageCode    =leakageCode    ,
+                 leakageObject  =leakageObject  ,
                  priority       =priority)
    return(aquifer)
 }
